@@ -29,10 +29,16 @@ class WSGIThreadPool(object):
                     break
                 response.dispatch()
             except Exception, e:
+                import sys, traceback
                 print "error:", e
                 print "todo: fix exception handling in threads"
+                print traceback.print_tb(sys.exc_info()[2])
         print "Shutting down thread", name
                 
     def stop(self):
         for t in self.threads:
             self.work_queue.put(None)
+        # We aren't cleaning up our threadpool. For now, we're making
+        # the assumption that if stop has been called it's because we
+        # caught ^C (or something) and so we aren't worrying about
+        # leaving stuff around.
